@@ -34,8 +34,10 @@ class SQLDBSource(SQLMixin, Source):
     ):
         super().__init__(*args, **kwargs)
 
-        if query is None and table_name is None:
-            raise InvalidArgumentsError("Both query and table_name cannot be none")
+        if not any([table_name, query, query_fn]):
+            raise InvalidArgumentsError(
+                "At least one of the query, table_name and query_fn must be specified"
+            )
 
         self.url = url
         self.table_name = table_name
@@ -45,8 +47,13 @@ class SQLDBSource(SQLMixin, Source):
         self.query_fn = query_fn
 
     def fetch(self, *args, **kwargs) -> SFrame:
-        query_result = self.get_from_db(text(self.get_query(*args, **kwargs)))
+        query_result = self.get_from_db(
+            text(self.get_query(self.filters, *args, **kwargs))
+        )
         return self.convert_data_type(query_result)
 
     def convert_data_type(self, data) -> SFrame:
         return super().convert_data_type(DFrame.from_raw(data).to_raw())
+
+    def calculate_complexity(self):
+        return 30
